@@ -159,7 +159,10 @@ class BeaconAPI(object):
 
         headers.update(self.headers)
 
-        r = requests.request(action, url, verify=True, headers=headers, **kw)
+        try:
+            r = requests.request(action, url, verify=True, headers=headers, **kw)
+        except requests.ConnectionError, e:
+            raise BeaconAPIException(code=500, message="Could not connect to server: %s" % e)
         self._debug('<< %s %s' % (r.status_code, r.reason))
         if 'x-typehint' in r.headers:
             self._debug('< x-typehint: %s' % r.headers['x-typehint'])
